#!/bin/sh
# *******************************************************************************
#  Lizenzmaterial - Eigentum der IBM
#  (c) Copyright IBM Corporation 2006, 2013. Alle Rechte vorbehalten.
#
# *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Umgebungsvariablen gemäß den Parametern und Standard-
# # werten im Script rm_upgrade.sh definieren
# #
# #===========================================================
# #
# # Diese Datei wird zu Beginn der Ausführung des Scripts
# # rm_upgrade.sh gelesen. Pro gültigem Parameter wird eine
# # Umgebungsvariable mit vordefiniertem Standardwert gesetzt.
# #
# # Benutzer können den Standardwert modifizieren und das
# # Script rm_upgrade.sh mit eigenen Werten starten. Die
# # Parameter und ihre Werte müssen dann nicht manuell in
# # der Befehlszeile eingegeben werden.
# #
# # WARNUNG:
# # Nicht alle Variablen müssen für jede Anwendung gesetzt
# # werden. Modifizieren Sie einen Wert erst, nachdem Sie
# # sorgfältig den zugehörigen Kommentar gelesen haben.
# #
# #############################################################

# Parameter: -oldApplicationHome
# Syntax: -oldApplicationHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum Ausgangsverzeichnis für Anwendungen
#  in der alten Installation
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Dies ist ein obligatorischer Parameter.
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conf' endet, z. B. /Jazz/IBM/RRC_3.x/jazz/server/conf.
#
OLD_APPLICATION_HOME=

# Parameter: -applicationContextRoot
# Syntax: -applicationContextRoot <Stammverzeichnis>
# Beschreibung:
# 	Kontextstammverzeichnis der Anwendung
# Standardwert:
# 	rm
# Einschränkungen:
#  - <Stammverzeichnis> muss ein gültiger Verzeichnisname
#    ohne vorangestellten Schrägstrich sein.
#
APPLICATION_CONTEXT_ROOT=

# Parameter: -oldJTSHome
# Syntax: -oldJTSHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum JTS-Ausgangsverzeichnis in der alten Installation
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit 'server/conf' endet.
#  - Nur für RM- und JTS-Upgrades gültig
#
OLD_JTS_HOME=

# Parameter: -oldJTSContextRoot
# Syntax: -oldJTSContextRoot <Stammverzeichnis>
# Beschreibung:
# 	JTS-Kontextstammverzeichnis der alten Installation
# Standardwert:
# 	jts
# Einschränkungen:
#  - Wird nur für RM-Upgrades akzeptiert.
#  - <Stammverzeichnis> muss ein gültiger Verzeichnisname
#    ohne vorangestellten Schrägstrich sein.
#
OLD_JTS_CONTEXT_ROOT=

# Parameter: -updateTomcatFiles
# Syntax: -updateTomcatFiles <yes | no>
# Beschreibung:
# 	Angabe, ob die Tomcat-Konfigurationsdateien aktualisiert
#  werden sollen.
# Standardwert:
# 	yes
# Einschränkungen:
#  - Gültig sind nur die Werte 'yes' und 'no'.
#
UPDATE_TOMCAT_FILES=yes

# Parameter: -oldApplicationTomcatHome
# Syntax: -oldApplicationTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum Tomcat-Stammverzeichnis für Anwendungen
#  in der alten Installation
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Wird nur für RM-Upgrades akzeptiert
#  - Das Verzeichnis muss vorhanden sein.
#
OLD_TOMCAT_HOME=

# Parameter: -oldJTSTomcatHome
# Syntax: -oldJTSTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum Tomcat-Stammverzeichnis für JTS in der alten Installation
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Wird nur für RM-Upgrades akzeptiert
#  - Das Verzeichnis muss vorhanden sein.
#
OLD_JTS_TOMCAT_HOME=

# Parameter: -newApplicationHome
# Syntax: -newApplicationHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Ausgangsverzeichnis für Anwendungen in der neuen Installation
# Standardwert:
# 	conf
# Einschränkungen:
#  - Nur für RTC-, QM- und RM-Upgrades akzeptiert und
#    in diesen Fällen ein obligatorischer Parameter
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conf' endet, z. B. /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf.
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parameter: -newJTSHome
# Syntax: -newJTSHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum JTS-Ausgangsverzeichnis des von der neuen Installation verwendeten JTS
# Standardwert:
# 	Ausgangsverzeichnis der neuen Anwendung
# Einschränkungen:
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conf' endet.
#
NEW_JTS_HOME=

# Parameter: -newJTSContextRoot
# Syntax: -newJTSContextRoot <Stammverzeichnis>
# Beschreibung:
# 	Kontextstammverzeichnis des neuen JTS
# Standardwert:
# 	jts
# Einschränkungen:
#  - <Stammverzeichnis> muss ein gültiger Verzeichnisname
#    ohne vorangestellten Schrägstrich sein.
#
JTS_CONTEXT_ROOT=jts

# Parameter: -newApplicationTomcatHome
# Syntax: -newApplicationTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Tomcat-Stammverzeichnis für Anwendungen in der neuen Installation
# Standardwert:
# 	<ohne>
#
NEW_TOMCAT_HOME=

# Parameter: -newJTSTomcatHome
# Syntax: -newJTSTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Tomcat-Stammverzeichnis für den von der neuen Installation verwendeten JTS
# Standardwert:
# 	<ohne>
#
NEW_JTS_TOMCAT_HOME=

# Parameter: -noPrompt
# Syntax: -noPrompt
# Beschreibung:
# 	Beim Ausführen von repotools-Befehlen keine Bestätigung anfordern
#  (d. h. immer noPrompt verwenden)
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Die einzigen gültigen Werte sind eine leere Zeichenfolge und 'noPrompt'.
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parameter: -overwrite
# Syntax: -overwrite
# Beschreibung:
# 	Beim Ausführen von repotools-Befehlen die Überschreibung immer
#  durchsetzen (d. h. immer overwrite=yes verwenden)
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Die einzigen gültigen Werte sind eine leere Zeichenfolge und 'overwrite=yes'.
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parameter: -noVerify
# Syntax: -noVerify
# Beschreibung:
# 	Beim Ausführen von repotools-Befehlen keine Verifizierung anfordern
#  (d. h. immer noVerify verwenden)
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Die einzigen gültigen Werte sind eine leere Zeichenfolge und 'noVerify'.
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parameter: -noStepPrompt
# Syntax: -noStepPrompt
# Beschreibung:
# 	Bei Upgradeschritten keine Bestätigung anfordern
#  (d. h. immer noPrompt verwenden)
# Standardwert:
# 	false
# Einschränkungen:
#  - Die einzigen gültigen Werte sind 'true' und 'false'.
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Parameter: -jtsURL
# Syntax: -jtsURL <öffentlicher URI von JTS>
# Beschreibung:
# 	Öffentlicher URI von JTS
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Nur bei einem Upgrade für RM akzeptiert
#  - Nur bei einer verteilten Implementierung notwendig, bei der JTS in einer anderen Serverinstanz als RM ausgeführt wird
#
JTS_PUBLIC_URL=
