#!/bin/sh
# *******************************************************************************
#  Materiales bajo licencia - Propiedad de IBM
#  (c) Copyright IBM Corporation 2006, 2013. Reservados todos los derechos.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Defina las variables de entorno correspondientes a los
# # parámetros del script rm_upgrade.sh y sus valores
# # predeterminados.
# #===========================================================
# #
# # Este archivo se lee al comienzo de la ejecución de la ejecución
# # del script rm_upgrade.sh. Define una variable de entorno por
# # cada parámetro válido con un valor predeterminado predefinido.
# #
# # Es posible que los usuarios deseen modificar el valor predeterminado
# # para lanzar el script rm_upgrade.sh con sus propios valores
# # sin tener que especificar de forma manual el parámetro y su
# # valor correspondiente en la línea de mandatos.
# #
# # AVISO:
# # No es necesario definir todas las variables para cada
# # aplicación.  Lea cada comentario detenidamente antes de modificar
# # el valor.
# #
# #############################################################

# Parámetro: -oldApplicationHome
# Uso: -oldApplicationHome <vía acceso dir>
# Descripción:
# 	Vía de acceso completa al directorio de inicio de la aplicación en la instalación anterior.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - es un parámetro obligatorio
#  - <vía acceso dir> debe ser un directorio existente terminado en 'server/conf'
#    por ej. /Jazz/IBM/RRC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Parámetro: -applicationContextRoot
# Uso: -applicationContextRoot <raíz>
# Descripción:
# 	Raíz de contexto de la aplicación.
# Valor predeterminado:
# 	rm
# Restricciones:
#  - <raíz> debe ser un nombre único de directorio válido (por ejemplo, sin ninguna barra inclinada inicial)
#
APPLICATION_CONTEXT_ROOT=

# Parámetro: -oldJTSHome
# Uso: -oldJTSHome <vía acceso dir>
# Descripción:
# 	Vía de acceso completa al directorio de inicio de JTS en la instalación anterior.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - <vía acceso dir> debe ser un directorio existente que termine en 'server/conf'
#  - Solo es válido para las actualizaciones de RM y JTS
#
OLD_JTS_HOME=

# Parámetro: -oldJTSContextRoot
# Uso: -oldJTSContextRoot <raíz>
# Descripción:
# Raíz de contexto de JTS de la instalación anterior.
# Valor predeterminado:
# 	jts
# Restricciones:
#  - Solo se acepta para la actualización de RM
#  - <raíz> debe ser un nombre único de directorio válido (por ejemplo, sin ninguna barra inclinada inicial)
#
OLD_JTS_CONTEXT_ROOT=

# Parámetro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descripción:
# Si deben actualizarse los archivos de configuración tomcat.
# Valor predeterminado:
# 	yes
# Restricciones:
#  - Los únicos valores válidos son 'yes' y 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parámetro: -oldApplicationTomcatHome
# Uso: -oldApplicationTomcatHome <vía acceso dir>
# Descripción:
# 	Vía de acceso completa al directorio raíz de Tomcat de la aplicación en la instalación anterior.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Solo se acepta para la actualización de RM
#  - Debe ser un directorio existente
#
OLD_TOMCAT_HOME=

# Parámetro: -oldJTSTomcatHome
# Uso: -oldJTSTomcatHome <vía acceso dir>
# Descripción:
# 	Vía de acceso completa al directorio raíz de Tomcat de JTS en la instalación anterior.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Solo se acepta para la actualización de RM
#  - Debe ser un directorio existente
#
OLD_JTS_TOMCAT_HOME=

# Parámetro: -newApplicationHome
# Uso: -newApplicationHome <vía acceso dir>
# Descripción:
# 	Vía de acceso al directorio de inicio de la aplicación de la nueva instalación.
# Valor predeterminado:
# 	conf
# Restricciones:
#  - Solo se acepta en actualizaciones RTC, QM y RM
#  - Cuando se acepta, es un parámetro obligatorio
#  - <vía acceso dir> debe ser un directorio existente que termine en 'server/conf'
#    por ej. /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parámetro: -newJTSHome
# Uso: -newJTSHome <vía acceso dir>
# Descripción:
# 	Vía de acceso al directorio de inicio de JTS en el JTS que la nueva instalación utilizará.
# Valor predeterminado:
# 	El nuevo directorio de inicio de aplicación
# Restricciones:
#  - <vía acceso dir> debe ser un directorio existente que termine en 'server/conf'
#
NEW_JTS_HOME=

# Parámetro: -newJTSContextRoot
# Uso: -newJTSContextRoot <raíz>
# Descripción:
# 	Raíz de contexto del nuevo servidor JTS.
# Valor predeterminado:
# 	jts
# Restricciones:
#  - <raíz> debe ser un nombre único de directorio válido (es decir, ninguna barra inclinada inicial)
#
JTS_CONTEXT_ROOT=jts

# Parámetro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <vía acceso dir>
# Descripción:
# 	Vía de acceso al directorio raíz Tomcat de la aplicación de la nueva instalación.
# Valor predeterminado:
# 	<ninguno>
#
NEW_TOMCAT_HOME=

# Parámetro: -newJTSTomcatHome
# Uso: -newJTSTomcatHome <vía acceso dir>
# Descripción:
# 	Vía de acceso al directorio raíz de Tomcat de JTS en el JTS que la nueva instalación utilizará.
# Valor predeterminado:
# 	<ninguno>
#
NEW_JTS_TOMCAT_HOME=

# Parámetro: -noPrompt
# Uso: -noPrompt
# Descripción:
# 	No solicita confirmación (es decir, utiliza siempre noPrompt) al ejecutar mandatos repotools
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los únicos valores válidos están vacíos o son 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parámetro: -overwrite
# Uso: -overwrite
# Descripción:
# 	Forzar la sobrescritura (es decir, utilizar siempre overwrite=yes) mientras se ejecutan mandatos repotools
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los únicos valores válidos están vacíos o son 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parámetro: -noVerify
# Uso: -noVerify
# Descripción:
# 	No realiza ninguna verificación (es decir, utiliza siempre noVerify) al ejecutar mandatos repotools
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los únicos valores válidos están vacíos o son 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parámetro: -noStepPrompt
# Uso: -noStepPrompt
# Descripción:
# 	No solicitar antes de cada paso de actualización
# Valor predeterminado:
# 	false
# Restricciones:
#  - Los únicos valores válidos son 'true' o 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Parámetro: -jtsURL
# Uso: -jtsURL <URI público JTS>
# Descripción:
# 	URI público del JTS
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Sólo aceptado para actualización de RM
#  - Sólo necesario en un despliegue distribuido donde se ejecuta JTS en una instancia de servidor distinta a la de la aplicación RM
#
JTS_PUBLIC_URL=
