#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Définissez les variables d'environnement correspondant
# # aux paramètres de script rm_upgrade.sh ainsi que leurs valeurs par défaut
# #
# #===========================================================
# #
# # Ce fichier est lu au début de l'exécution du script
# # rm_upgrade.sh. Il associe une variable d'environnement
# # par paramètre valide à une valeur par défaut prédéfinie.
# #
# # Les utilisateurs peuvent modifier la valeur par défaut
# # pour lancer le script rm_upgrade.sh avec leurs propres
# # valeurs sans avoir à entrer manuellement le paramètre et
# # sa valeur correspondante sur la ligne de commande.
# #
# # AVERTISSEMENT :
# # Les variables ne doivent pas toutes être définies pour chaque
# # application.  Lisez avec attention chaque commentaire avant de
# # modifier la valeur.
# #
# #############################################################

# Paramètre : -oldApplicationHome
# Syntaxe : -oldApplicationHome <chemin rép>
# Description :
# 	Chemin d'accès complet au répertoire principal de l'application dans l'ancienne installation.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Il s'agit d'un paramètre obligatoire
#  - <chemin rép> doit correspondre à un répertoire existant se terminant par 'server/conf'
#    par exemple : /Jazz/IBM/RRC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Paramètre : -applicationContextRoot
# Syntaxe : -applicationContextRoot <racine>
# Description :
# 	Racine de contexte d'application.
# Valeur par défaut :
# 	rm
# Contraintes :
#  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début)
#
APPLICATION_CONTEXT_ROOT=

# Paramètre : -oldJTSHome
# Syntaxe : -oldJTSHome <chemin rép>
# Description :
# 	Chemin d'accès complet au répertoire principal JTS dans l'ancienne installation.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - <chemin répertoire> doit correspondre à un répertoire existant se terminant par 'server/conf'
#  - Valide uniquement pour les mises à niveau de RM et JTS
#
OLD_JTS_HOME=

# Paramètre : -oldJTSContextRoot
# Syntaxe : -oldJTSContextRoot <racine>
# Description :
# 	Racine de contexte JTS de l'ancienne installation.
# Valeur par défaut :
# 	jts
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RM
#  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début)
#
OLD_JTS_CONTEXT_ROOT=

# Paramètre : -updateTomcatFiles
# Syntaxe : -updateTomcatFiles <yes | no>
# Description :
# 	Indique si les fichiers de configuration Tomcat doivent être mis à jour.
# Valeur par défaut :
# 	yes
# Contraintes :
#  - Seules les valeurs 'yes' et 'no' sont valides
#
UPDATE_TOMCAT_FILES=yes

# Paramètre : -oldApplicationTomcatHome
# Syntaxe : -oldApplicationTomcatHome <chemin rép>
# Description :
# 	Chemin d'accès complet au répertoire racine Tomcat de l'application dans l'ancienne installation.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RM
#  - Doit être un répertoire existant
#
OLD_TOMCAT_HOME=

# Paramètre : -oldJTSTomcatHome
# Syntaxe : -oldJTSTomcatHome <chemin rép>
# Description :
# 	Chemin d'accès complet au répertoire racine Tomcat JTS dans l'ancienne installation.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RM
#  - Doit être un répertoire existant
#
OLD_JTS_TOMCAT_HOME=

# Paramètre : -newApplicationHome
# Syntaxe : -newApplicationHome <chemin rép>
# Description :
# 	Chemin d'accès au répertoire principal de l'application dans la nouvelle installation.
# Valeur par défaut :
# 	conf
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RTC, QM et RM
#  - Lorsqu'il est admis, il s'agit d'un paramètre obligatoire
#  - <chemin rép> doit correspondre à un répertoire existant se terminant par 'server\conf'
#    exemple : /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Paramètre : -newJTSHome
# Syntaxe : -newJTSHome <chemin rép>
# Description :
# 	Chemin d'accès complet au répertoire principal du serveur JTS que la nouvelle installation va utiliser.
# Valeur par défaut :
# 	Répertoire principal de la nouvelle application
# Contraintes :
#  - <chemin rép> doit correspondre à un répertoire existant se terminant par 'server\conf'
#
NEW_JTS_HOME=

# Paramètre : -newJTSContextRoot
# Syntaxe : -newJTSContextRoot <racine>
# Description :
# 	Racine de contexte du nouveau serveur JTS.
# Valeur par défaut :
# 	jts
# Contraintes :
#  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début)
#
JTS_CONTEXT_ROOT=jts

# Paramètre : -newApplicationTomcatHome
# Syntaxe : -newApplicationTomcatHome <chemin rép>
# Description :
# 	Chemin d'accès au répertoire racine Tomcat de l'application dans la nouvelle installation.
# Valeur par défaut :
# 	<aucune>
#
NEW_TOMCAT_HOME=

# Paramètre : -newJTSTomcatHome
# Syntaxe : -newJTSTomcatHome <chemin rép>
# Description :
# 	Chemin d'accès au répertoire racine Tomcat du serveur JTS que la nouvelle application va utiliser.
# Valeur par défaut :
# 	<aucune>
#
NEW_JTS_TOMCAT_HOME=

# Paramètre : -noPrompt
# Syntaxe : -noPrompt
# Description :
# 	Ne pas demander confirmation (toujours utiliser noPrompt) lors de l'exécution des commandes repotools
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs valides sont la valeur vide et la valeur 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Paramètre : -overwrite
# Syntaxe : -overwrite
# Description :
# 	Forcer le remplacement (toujours utiliser overwrite=yes) lors de l'exécution des commandes repotools
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs valides sont la valeur vide et la valeur 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Paramètre : -noVerify
# Syntaxe : -noVerify
# Description :
# 	Ne pas demander de vérification (toujours utiliser noVerify) lors de l'exécution des commandes repotools
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs valides sont la valeur vide et la valeur 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Paramètre : -noStepPrompt
# Syntaxe : -noStepPrompt
# Description :
# 	Ne pas demander confirmation avant chaque étape de mise à niveau
# Valeur par défaut :
# 	false
# Contraintes :
#  - Les seules valeurs valides sont 'true' et 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Paramètre : -jtsURL
# Syntaxe : -jtsURL <URI public JTS>
# Description :
# 	URI public du serveur JTS
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RM
#  - Nécessaire uniquement dans un déploiement réparti où le serveur JTS s'exécute sur une instance de serveur différente de celle de l'application RM
#
JTS_PUBLIC_URL=
