#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # 定義對應至 rm_upgrade.sh Script
# # 參數的環境變數及其預設值
# #
# #===========================================================
# #
# # 開始執行 rm_upgrade.sh Script 時，會
# # 讀取這個檔案。它會利用預先定義的預設值，
# # 針對每個有效的參數來設定一個環境變數。
# #
# # 使用者可能會想修改預設值，以他們本身
# # 的值來啟動 rm_upgrade.sh Script，而
# # 不必在指令行中手動輸入參數及其對應的
# # 值。                                    
# #
# # 警告：
# # 對每一個應用程式來說，並非所有的變數
# # 都需要設定。修改值之前，請仔細閱讀每
# # 一則註解。
# #
# #############################################################

# 參數：-oldApplicationHome
# 用法：-oldApplicationHome <dir path>
# 說明：
# 	舊安裝架構中應用程式起始目錄的完整路徑。
# 預設值：
# <無>
# 限制：
#  - 這是必要參數
#  - <dir path> 必須是現有目錄，且結尾是 'server/conf'
#    例如 /Jazz/IBM/RRC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# 參數：-applicationContextRoot
# 用法：-applicationContextRoot <root>
# 說明：
# 	應用程式環境定義根目錄。
# 預設值：
# 	rm
# 限制：
#  - <root> 必須是有效的目錄單一名稱（例如，沒有前導斜線）
#
APPLICATION_CONTEXT_ROOT=

# 參數：-oldJTSHome
# 用法：-oldJTSHome <dir path>
# 說明：
# 	舊安裝架構中 JTS 起始目錄的完整路徑。
# 預設值：
# 	<無>
# 限制：
#  - <dir path> 必須是現有目錄，且結尾是 'server/conf'
#  - 僅適用於 RM 和 JTS 升級作業
#
OLD_JTS_HOME=

# 參數：-oldJTSContextRoot
# 用法：-oldJTSContextRoot <root>
# 說明：
# 	JTS 伺服器的環境定義根目錄。
# 預設值：
# 	jts
# 限制：
#  - 僅接受 RM 升級
#  - <root> 必須是有效的目錄單一名稱（例如，沒有前導斜線）
#
OLD_JTS_CONTEXT_ROOT=

# 參數：-updateTomcatFiles
# 用法：-updateTomcatFiles <yes | no>
# 說明：
# 	是否更新 Tomcat 配置檔。
# 預設值：
# 	yes
# 限制：
#  - 唯一有效值是 'yes' 和 'no'
#
UPDATE_TOMCAT_FILES=yes

# 參數：-oldApplicationTomcatHome
# 用法：-oldApplicationTomcatHome <dir path>
# 說明：
# 	舊安裝架構中應用程式 Tomcat 根目錄的完整路徑。
# 預設值：
# 	<無>
# 限制：
#  - 必須是 RM 升級作業，才會接受這個參數
#  - 必須是現有的目錄
#
OLD_TOMCAT_HOME=

# 參數：-oldJTSTomcatHome
# 用法：-oldJTSTomcatHome <dir path>
# 說明：
# 	舊安裝架構中 JTS Tomcat 根目錄的完整路徑。
# 預設值：
# 	<無>
# 限制：
#  - 必須是 RM 升級作業，才會接受這個參數
#  - 必須是現有的目錄
#
OLD_JTS_TOMCAT_HOME=

# 參數：-newApplicationHome
# 用法：-newApplicationHome <dir path>
# 說明：
# 	新安裝架構中應用程式起始目錄的路徑。
# 預設值：
# 	conf
# 限制：
#  - 必須是 RTC、QM 和 RM 升級作業，才會接受此參數
#  - 當接受時，這是必要參數
#  - <dir path> 必須是現有目錄，且結尾是 'server/conf'
#    例如 /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# 參數：-newJTSHome
# 用法：-newJTSHome <dir path>
# 說明：
# 	新安裝架構將使用之 JTS 中 JTS 起始目錄的完整路徑。
# 預設值：
# 	新應用程式起始目錄
# 限制：
#  - <dir path> 必須是現有目錄，且結尾是 'server/conf'
#
NEW_JTS_HOME=

# 參數：-newJTSContextRoot
# 用法：-newJTSContextRoot <root>
# 說明：
# 	JTS 伺服器的環境定義根目錄。
# 預設值：
# 	jts
# 限制：
#  - <root> 必須是有效的目錄單一名稱（例如，沒有前導斜線）
#
JTS_CONTEXT_ROOT=jts

# 參數：-newApplicationTomcatHome
# 用法：-newApplicationTomcatHome <dir path>
# 說明：
# 	新安裝架構中應用程式 Tomcat 根目錄的路徑。
# 預設值：
# 	<無>
#
NEW_TOMCAT_HOME=

# 參數：-newJTSTomcatHome
# 用法：-newJTSTomcatHome <dir path>
# 說明：
# 	新安裝架構將使用之 JTS 中 JTS Tomcat 根目錄的路徑。
# 預設值：
# 	<無>
#
NEW_JTS_TOMCAT_HOME=

# 參數：-noPrompt
# 用法：-noPrompt
# 說明：
# 	執行任何 repotools 指令時，不提示您進行任何確認（例如，一律使用 noPrompt）
# 預設值：
# 	<無>
# 限制：
#  - 唯一的有效值是空的或 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# 參數：-overwrite
# 用法：-overwrite
# 說明：
# 	執行任何 repotools 指令時強制改寫（例如，一律使用 overwrite=yes）
# 預設值：
# 	<無>
# 限制：
#  - 唯一的有效值是空的或 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# 參數：-noVerify
# 用法：-noVerify
# 說明：
# 	執行任何 repotools 指令時，不進行任何驗證（例如，一律使用 noVerify）
# 預設值：
# 	<無>
# 限制：
#  - 唯一的有效值是空的或 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# 參數：-noStepPrompt
# 用法：-noStepPrompt
# 說明：
# 	在執行每個升級步驟之前不先提示
# 預設值：
# 	false
# 限制：
#  - 唯一的有效值是 'true' 或 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false


# 參數：-jtsURL
# 用法：-jtsURL <JTS public URI>
# 說明：
# 	公用 JTS 的 URI
# 預設值：
# 	<無>
# 限制：
#  - 僅接受 RM 升級
#  - 只有在 JTS 是在與 RM 應用程式不同的伺服器實例上執行的分散式部署中才需要。
#
JTS_PUBLIC_URL=
